<?php

namespace Drupal\entity_share_cron;

/**
 * Entity Share Cron service.
 */
interface EntityShareCronServiceInterface {

  const PENDING_QUEUE_NAME = 'entity_share_cron_pending';

  /**
   * Enqueues a channel for later synchronization.
   *
   * @param string $remote_id
   *   The ID of the remote the channel belongs to.
   * @param string $channel_id
   *   The ID of the channel to be enqueued.
   * @param array $channel_info
   *   Channel info.
   */
  public function enqueue($remote_id, $channel_id, array $channel_info);

  /**
   * Synchronizes entities starting from provided channel URL.
   *
   * @param string $remote_id
   *   The ID of the remote the channel belongs to.
   * @param string $channel_id
   *   The ID of the channel to be synchronized.
   * @param array $channel_info
   *   Channel info.
   * @param int $page_limit
   *   The maximum number of pages to process. The remaining will be enqueued.
   */
  public function sync($remote_id, $channel_id, array $channel_info, $page_limit = 0);

}
